@@ -86,7 +86,7 @@
 #define KNEWSTUFF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFF_NO_DEPRECATED
-#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KNEWSTUFF_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -234,7 +234,7 @@
 #define KNEWSTUFF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFF_NO_DEPRECATED
-#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KNEWSTUFF_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0
@@ -244,7 +244,7 @@
 #  ifdef KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
